TokenWrapError

Enum TokenWrapError 

pub enum TokenWrapError {
Show 16 variants WrappedMintMismatch, BackpointerMismatch, ZeroWrapAmount, MintAuthorityMismatch, EscrowOwnerMismatch, InvalidWrappedMintOwner, InvalidBackpointerOwner, EscrowMismatch, EscrowInGoodState, UnwrappedMintHasNoMetadata, MetaplexMetadataMismatch, MetadataPointerMissing, MetadataPointerUnset, MetadataPointerMismatch, ExternalProgramReturnedNoData, NoSyncingToToken2022,
}
Errors that may be returned by the Token Wrap program.

Variants



WrappedMintMismatch

Wrapped mint account address does not match expected PDA



BackpointerMismatch

Wrapped backpointer account address does not match expected PDA



ZeroWrapAmount

Wrap amount should be positive



MintAuthorityMismatch

Wrapped mint authority does not match expected PDA



EscrowOwnerMismatch

Unwrapped escrow token owner is not set to expected PDA



InvalidWrappedMintOwner

Wrapped mint account owner is not the expected token program



InvalidBackpointerOwner

Wrapped backpointer account owner is not the expected token wrap program



EscrowMismatch

Escrow account address does not match expected ATA



EscrowInGoodState

The escrow account is in a good state and cannot be recreated



UnwrappedMintHasNoMetadata

Unwrapped mint does not have the TokenMetadata extension



MetaplexMetadataMismatch

Metaplex metadata account address does not match expected PDA



MetadataPointerMissing

Metadata pointer extension missing on mint



MetadataPointerUnset

Metadata pointer is unset (None)



MetadataPointerMismatch

Provided source metadata account does not match pointer



ExternalProgramReturnedNoData

External metadata program returned no data



NoSyncingToToken2022

Instruction can only be used with spl-token wrapped mints