Module metadata

Module metadata 

Metadata resolution helpers for pointer-aware metadata sync

Functions

cpi_emit_and_decode
Fetches metadata from a third-party program implementing TokenMetadataInstruction by invoking its Emit instruction and decoding the TokenMetadata struct from the return data.
extract_token_metadata
Extracts the token metadata from the unwrapped mint
resolve_token_2022_source_metadata
Resolve the canonical metadata source for an unwrapped Token-2022 mint by following its MetadataPointer.